MethodChannelFileLauncher class

Native method-channel implementation of FileLauncherPlatform.

Inheritance

Constructors

MethodChannelFileLauncher()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
Channel used to communicate with Android and iOS.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open(String filePath, {String? title, String? mimeType}) → Future<OpenFileResult>
Opens a local file using native presentation.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited