FileLauncherPlatform class abstract

Interface implemented by native file launchers.

Inheritance
  • Object
  • PlatformInterface
  • FileLauncherPlatform
Implementers

Constructors

FileLauncherPlatform()
Constructs a platform implementation with a verified token.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open(String filePath, {String? title, String? mimeType}) → Future<OpenFileResult>
Opens a local file using native presentation.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ FileLauncherPlatform
The current platform implementation.
getter/setter pair